<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

<xsl:include href="fo-common.xsl"/>
<xsl:include href="crossref-pdf.xsl"/>

<xsl:variable name="font" select="sans-serif"/>

<xsl:template match="Manual">

<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
<fo:layout-master-set>
<!-- template set for different types of pages -->
<!-- the first page template -->
<fo:simple-page-master master-name="first" page-height="29.7cm" page-width="21cm" margin-top="1cm" margin-bottom="2cm" margin-left="2.5cm" margin-right="2.5cm">
<fo:region-start extent="1cm"/>
<fo:region-body margin-top="3cm" margin-left="2cm"/>
<fo:region-before precedence="true" extent="3cm"/>
<fo:region-after extent="1.5cm"/>
</fo:simple-page-master>

<!-- the preface page template -->
<fo:simple-page-master master-name="preface" page-height="29.7cm" page-width="21cm" margin-top="1cm" margin-bottom="2cm" margin-left="2.5cm" margin-right="2.5cm">
<fo:region-body margin-top="3cm"/>
<fo:region-before extent="3cm"/>
<fo:region-after extent="1.5cm"/>
</fo:simple-page-master>

<!-- the acknowledgements page template -->
<fo:simple-page-master master-name="acknowledgements" page-height="29.7cm" page-width="21cm"
margin-top="1cm" margin-bottom="2cm" margin-left="2.5cm" margin-right="2.5cm">
<fo:region-body margin-top="3cm"/>
<fo:region-before extent="3cm"/>
<fo:region-after extent="1.5cm"/>
</fo:simple-page-master>

<!-- the table of content page template -->
<fo:simple-page-master master-name="ToC" page-height="29.7cm" page-width="21cm" margin-top="1cm" margin-bottom="2cm" margin-left="2.5cm" margin-right="2.5cm">
<fo:region-body margin-top="3cm"/>
<fo:region-before extent="3cm"/>
<fo:region-after extent="1.5cm"/>
</fo:simple-page-master>

<!-- the document page template -->
<fo:simple-page-master master-name="document" page-height="29.7cm" page-width="21cm" margin-top="1cm" margin-bottom="2cm" margin-left="2.5cm" margin-right="2.5cm">
<fo:region-body margin-top="3cm"/>
<fo:region-before extent="3cm" precedence="true" display-align="after"/>
<fo:region-after extent="1.5cm"/>
</fo:simple-page-master>
</fo:layout-master-set>



<!-- Cover Page-->

<fo:page-sequence master-reference="first">
<fo:static-content flow-name="xsl-region-start">
<!-- left banner image -->
<fo:block-container height="29cm" width="2cm" left="0cm" top="0cm">
<fo:block><fo:external-graphic src="url('Install_files/image001.jpg')" height="29cm"/></fo:block>
</fo:block-container>
</fo:static-content>
<fo:flow flow-name="xsl-region-body">
<xsl:apply-templates select="Heading/Text" mode="heading"/>
<xsl:apply-templates select="Title"/>
<xsl:apply-templates select="Author"/>
<xsl:apply-templates select="Affiliation"/>
<xsl:apply-templates select="Text"/>
<xsl:apply-templates select="Comment"/>
<xsl:apply-templates select="Version"/>
</fo:flow>
</fo:page-sequence>



<!-- Preface -->

<fo:page-sequence master-reference="preface">
<fo:flow flow-name="xsl-region-body">
<xsl:for-each select="Section[not(@id='acknowledgements')]"><xsl:apply-templates/></xsl:for-each>
</fo:flow>
</fo:page-sequence>

<fo:page-sequence master-reference="acknowledgements">
<fo:flow flow-name="xsl-region-body"><xsl:apply-templates select="Section[@id='acknowledgements']"/></fo:flow>
</fo:page-sequence>



<!-- ToC Page -->

<fo:page-sequence master-reference="ToC">
<fo:flow flow-name="xsl-region-body">
<fo:block text-align="right" font-size="24.0pt" line-height="24pt" space-after.optimum="25pt" padding-top="3pt">Contents</fo:block>
<xsl:for-each select="Chapter">
  <xsl:variable name="show_number">
    <xsl:if test="starts-with(@id, 'appendix') or starts-with(@id, 'biblio')">n</xsl:if>
    <xsl:if test="not(starts-with(@id, 'appendix')) and not(starts-with(@id, 'biblio'))">y</xsl:if>
  </xsl:variable>
  <fo:block text-align="start" font-size="15.0pt" line-height="15pt" text-align-last="justify" space-before.optimum="15pt" padding-top="3pt">
  <fo:basic-link color="black" internal-destination="Chapter_{@id}">
  <xsl:if test="$show_number='y'"><xsl:number/>&#160;&#160;</xsl:if>
  <xsl:apply-templates select="Title/Text"/>
  <fo:leader leader-pattern="space"/>
  <fo:page-number-citation ref-id="Chapter_{@id}"/>
  </fo:basic-link>
  </fo:block>

  <xsl:for-each select="Content/Section">
    <fo:block text-align="start" font-size="10.0pt" font-weight="bold" text-align-last="justify" padding-top="3pt" space-before.optimum="15pt" margin-left="12pt">
    <fo:basic-link color="black" internal-destination="Section_{@id}">
    <xsl:if test="$show_number='y'"><xsl:number level="multiple" count="Chapter|Chapter/Content/Section" format="1.1"/>&#160;&#160;</xsl:if>
    <xsl:apply-templates select="Title/Text"/>
    <fo:leader leader-pattern="space"/>
    <fo:page-number-citation ref-id="Section_{@id}"/>
    </fo:basic-link>
    <xsl:for-each select="Content/Subsection"><xsl:call-template name="SubsectionLink"/></xsl:for-each>
    </fo:block>
  </xsl:for-each>
</xsl:for-each>



<!-- figure and table lists -->
<!--
<xsl:if test="not(count(//Figure[not(normalize-space(Title/Text)='')])=0)">
<fo:block break-before="page" space-before.optimum="50pt" space-after.optimum="15pt" font-size="15pt" font-weight="bold">Figures</fo:block>
<xsl:for-each select="//Figure">
<fo:block text-align="start" font-size="10.0pt" font-weight="bold" text-align-last="justify">
<fo:basic-link color="black" internal-destination="Figure_{@id}">
<xsl:apply-templates select="Title/Text"/>
<fo:leader leader-pattern="space"/>
<fo:page-number-citation ref-id="Figure_{@id}"/>
</fo:basic-link>
</fo:block>
</xsl:for-each>
</xsl:if>

<xsl:if test="not(count(//Table[not(normalize-space(Title/Text)='')])=0)">
<fo:block break-before="page" space-before.optimum="50pt" space-after.optimum="15pt" font-size="15pt" font-weight="bold">Tables</fo:block>
<xsl:for-each select="//Table[not(@class='hidden')]">
<fo:block text-align="start" font-size="10.0pt" font-weight="bold" text-align-last="justify">
<fo:basic-link color="black" internal-destination="Table_{@id}">
<xsl:apply-templates select="Title/Text"/>
<fo:leader leader-pattern="space"/>
<fo:page-number-citation ref-id="Table_{@id}"/>
</fo:basic-link>
</fo:block>
</xsl:for-each>
</xsl:if>
-->

</fo:flow>
</fo:page-sequence>



<!-- Document -->

<fo:page-sequence master-reference="document" initial-page-number="1">
<!-- defines header of a page -->
<fo:static-content flow-name="xsl-region-before">
<xsl:variable name="pageno"><fo:page-number/></xsl:variable>
<xsl:choose>
<xsl:when test="$pageno='1'">
<fo:block-container height="1cm" width="18cm" left="0cm" top="0cm" display-align="after">
<fo:block text-align="start" font-size="10pt" font-family="{$font}" line-height="14pt">greenstone.org<fo:external-graphic src="url('_files/header.gif')"/>
</fo:block>
</fo:block-container>
</xsl:when>
<xsl:otherwise>
<fo:block-container height="1cm" width="18cm" left="0cm" top="0cm" display-align="after">
<fo:block text-align="start" font-size="10pt" font-family="{$font}" line-height="14pt">
<fo:page-number/>&#160;&#160;
<fo:retrieve-marker retrieve-class-name="head" retrieve-position="first-including-carryover" retrieve-boundary="page-sequence"/>
</fo:block>
</fo:block-container>
</xsl:otherwise>
</xsl:choose>
</fo:static-content>

<!-- footer of a page -->
<fo:static-content flow-name="xsl-footnote-separator">
<fo:block><fo:leader leader-pattern="rule" leader-length="100%" rule-style="solid" rule-thickness="0.5pt"/></fo:block>
</fo:static-content>

<fo:flow flow-name="xsl-region-body">
<xsl:for-each select="Chapter">
<!-- header -->
<fo:block><fo:marker marker-class-name="head"><xsl:value-of select="Title"/></fo:marker></fo:block>
<xsl:apply-templates/>
<xsl:if test="not(count(following-sibling::*[not(name()='FootnoteList')])=0)">
<fo:block break-after="page"/>
</xsl:if>
</xsl:for-each>

</fo:flow>
</fo:page-sequence>
</fo:root>
</xsl:template>



<xsl:template name="SubsectionLink">
<fo:block text-align="start" font-size="10.0pt" text-align-last="justify" margin-left="25pt" padding-top="3pt">
<fo:basic-link color="black">
<xsl:attribute name="internal-destination">Subsection_<xsl:value-of select="@id"/></xsl:attribute>
<xsl:apply-templates select="Title/Text"/>
<fo:leader leader-pattern="space"/>
<fo:page-number-citation ref-id="Subsection_{@id}"/>
</fo:basic-link>
</fo:block>
</xsl:template>
</xsl:stylesheet>
