#!/usr/local/bin/perl5 -w

# This program will output the text for a particular index

BEGIN {
    die "GSDLHOME not set\n" unless defined $ENV{'GSDLHOME'};
    die "GSDLOS not set\n" unless defined $ENV{'GSDLOS'};
    unshift (@INC, "$ENV{'GSDLHOME'}/lib");
    unshift (@INC, "$ENV{'GSDLHOME'}/lib/plugins");
}

use parsargv;
use plugin;
use colcfg;

sub print_usage {
    print STDERR "\n  usage: $0 collection-name\n";
    print STDERR "  options:\n";
    print STDERR "   -index index   The index to output\n\n";
}


&main ();

sub main {

    if (!parsargv::parse(\@ARGV, 
			 'index/.*/section:text', \$index,
			 'mode/.*/text', \$mode)) {
	&print_usage();
	die "\n";
    }

    # get and check the collection name
    ($collection) = @ARGV;

    if (!defined($collection)) {
	&print_usage();
	die "\n";
    }
    
    # get the list of plugins for this collection
    @plugins = ("RecPlug", "HTMLPlug", "TXTPlug");
    if (-e "$ENV{'GSDLHOME'}/collect/$collection/collect.cfg") {
	$collectcfg = &colcfg::read_collect_cfg ("$ENV{'GSDLHOME'}/collect/$collection/collect.cfg");
	if (defined $collectcfg->{'plugins'}) {
	    @plugins = @{$collectcfg->{'plugins'}};
	}
    }
    

    # load all the plugins
    $pluginfo = &plugin::load_plugins ($collection, \@plugins);
    if (scalar(@$pluginfo) == 0) {
	print STDERR "No plugins were loaded.\n";
	die "\n";
    }

    # load up the document processor for building
    # if a buildproc class has been created for this collection, use it
    # otherwise, use the mg buildproc
    my ($buildprocdir, $buildproctype);
    if (-e "$ENV{'GSDLHOME'}/collect/$collection/lib/${collection}buildproc.pm") {
	$buildprocdir = "$ENV{'GSDLHOME'}/collect/$collection/lib";
	$buildproctype = "${collection}buildproc";
    } else {
	$buildprocdir = "$ENV{'GSDLHOME'}/lib";
	$buildproctype = "mgbuildproc";
    }
    require "$buildprocdir/$buildproctype.pm";

    my $source_dir = "$ENV{'GSDLHOME'}/collect/$collection/archives";
    my $build_dir = "$ENV{'GSDLHOME'}/collect/$collection/building";
    my $verbosity = 1;

    eval("\$buildproc = new $buildproctype(\$collection, " .
	 "\$source_dir, \$build_dir, \$verbosity)");
    die "$@" if $@;

    # set up the document processor
    $buildproc->set_output_handle ('STDOUT');
    $buildproc->set_mode ($mode);
    $buildproc->set_index ($index);

    $buildproc->reset();

    # process the import directory
    &plugin::read ($pluginfo, $source_dir, 
		   "", {}, $buildproc);

}
